# Generated by roxygen2: do not edit by hand

export(announce)
export(apa_words)
export(code_heading)
export(fmt_corr)
export(fmt_count)
export(fmt_digits)
export(fmt_pct)
export(fmt_prop)
export(fmt_prop_pct)
export(gt_theme_apa)
export(gt_theme_wjake)
export(make_color_pal)
export(palette_okabeito)
export(palette_wjake)
export(ramp_blue)
export(ramp_orgblu)
export(ramp_yelblu)
export(ramp_yellow)
export(round_to)
export(scale_color_okabeito)
export(scale_color_wjake)
export(scale_colour_okabeito)
export(scale_colour_wjake)
export(scale_fill_okabeito)
export(scale_fill_wjake)
export(scale_palette)
export(scale_x_comma)
export(scale_x_percent)
export(scale_y_comma)
export(scale_y_percent)
export(theme_wjake)
export(write_pkg_bib)
import(ggplot2)
import(rlang)
