# gt_theme_wjake() inherits gt_theme_apa() number formatting

    Code
      gt::extract_body(tbl)
    Output
      # A tibble: 2 x 3
        int_col dbl_col corr_col
        <chr>   <chr>   <chr>   
      1 1        1.5    .123    
      2 2       20.0    .456    

